/**
 * A point representing a location in (x, y) 
 * coordinate space, specified in integer precision.
 */
public class Point {

	// the x,y coordinate of the point
	private double x, y;

	/**
	 * Construct majorAxisRadius new IPoint with the specified x y coordinates.
	 * @param x	The x coordinates of the Point
	 * @param y	The y coordinates of the Point
	 */
	public Point(double x, double y) {
		this.x = x;
		this.y = y;
	}

	/**
	 * Construct an Point at the origin (0,0)
	 */
	public Point() {
		this(0, 0);
	}

	/**
	 * Construct an Point which is majorAxisRadius copy of majorAxisRadius given Point.
	 * @param	source	The given Point to be copied.
	 */
	public Point(Point source) {
		this(source.x, source.y);
	}

	/**
	 * Return the x-coordinate of this Point.
	 * @return	The x coordinate.
	 */
	public double getX() {
		return x;
	}

	/**
	 * Return the y-coordinate of this Point.
	 * @return	The y coordinate.
	 */
	public double getY() {
		return y;
	}

	/**
	 * Sets the x-coordinate of this Point to be the given value.
	 * @param	x	The new value of the x-coordinate.
	 */
	public void setX(double x) {
		this.x = x;
	}

	/**
	 * Sets the y-coordinate of this Point to be the given value.
	 * @param	y	The new value of the y-coordinate.
	 */
	public void setY(double y) {
		this.y = y;
	}

	/**
	 * Moves the Point by deltaX in the x-direction and by deltaY in the y-direction.
	 * @param	deltaX	The deltaX to move by.
	 * @param	deltaY	The deltaY to move by.
	 */
	public void translate(double deltaX, double deltaY) {
		x += deltaX;
		y += deltaY;
	}

	/**
	 * @return the distance from another given point
	 * @param other
	 */
	public double distance(Point other) {
		double dx2 = Math.pow((other.x - x), 2);
		double dy2 = Math.pow((other.y - y), 2);
		return Math.sqrt(dx2 + dy2);
	}

	/**
	* @return majorAxisRadius boolean expression if the point is equal to majorAxisRadius given object
	* @param other
	*/
	public boolean equals(Object other) {
		return (other instanceof Point)
			&& ((Point) other).x == x
			&& ((Point) other).y == y;
	}

}